@@ -1,16 +1,12 @@
 /*
  * SNMP discovery backend for CUPS.
  *
- * Copyright 2007-2014 by Apple Inc.
- * Copyright 2006-2007 by Easy Software Products, all rights reserved.
+ * Copyright © 2020-2024 by OpenPrinting.
+ * Copyright © 2007-2014 by Apple Inc.
+ * Copyright © 2006-2007 by Easy Software Products, all rights reserved.
  *
- * These coded instructions, statements, and computer programs are the
- * property of Apple Inc. and are protected by Federal copyright
- * law.  Distribution and use rights are outlined in the file "LICENSE.txt"
- * "LICENSE" which should have been included with this file.  If this
- * file is missing or damaged, see the license at "http://www.cups.org/".
- *
- * This file is subject to the Apple OS-Developed Software exception.
+ * Licensed under Apache License v2.0.  See the file "LICENSE" for more
+ * information.
  */
 
 /*
@@ -18,6 +14,9 @@
  */
 
 #include "backend-private.h"
+#ifndef HAVE_GETIFADDRS
+#  include <cups/getifaddrs-internal.h>
+#endif // !HAVE_GETIFADDRS
 #include <cups/array.h>
 #include <cups/file.h>
 #include <cups/http-private.h>
@@ -159,6 +158,8 @@ static const int	UriOID[] = { CUPS_OID_ppmPortServiceNameOrURI, 1, 1, -1 };
 static const int	LexmarkProductOID[] = { 1,3,6,1,4,1,641,2,1,2,1,2,1,-1 };
 static const int	LexmarkProductOID2[] = { 1,3,6,1,4,1,674,10898,100,2,1,2,1,2,1,-1 };
 static const int	LexmarkDeviceIdOID[] = { 1,3,6,1,4,1,641,2,1,2,1,3,1,-1 };
+static const int	HPDeviceIdOID[] = { 1,3,6,1,4,1,11,2,3,9,1,1,7,0,-1 };
+static const int	RicohDeviceIdOID[] = { 1,3,6,1,4,1,367,3,2,1,1,1,11,0,-1 };
 static const int	XeroxProductOID[] = { 1,3,6,1,4,1,128,2,1,3,1,2,0,-1 };
 static cups_array_t	*DeviceURIs = NULL;
 static int		HostNameLookups = 0;
@@ -298,7 +299,12 @@ add_cache(http_addr_t *addr,		/* I - Device IP address */
                addr, addrname, uri ? uri : "(null)", id ? id : "(null)",
 	       make_and_model ? make_and_model : "(null)");
 
-  temp = calloc(1, sizeof(snmp_cache_t));
+  if ((temp = calloc(1, sizeof(snmp_cache_t))) == NULL)
+  {
+    perror("DEBUG: Unable to allocate cache entry");
+    return;
+  }
+
   memcpy(&(temp->address), addr, sizeof(temp->address));
 
   temp->addrname = strdup(addrname);
@@ -427,7 +433,7 @@ alarm_handler(int sig)			/* I - Signal number */
 #endif /* !HAVE_SIGSET && !HAVE_SIGACTION */
 
   if (DebugLevel)
-    write(2, "DEBUG: ALARM!\n", 14);
+    backendMessage("DEBUG: ALARM!\n");
 }
 
 
@@ -616,22 +622,25 @@ get_interface_addresses(
     return (NULL);
 
   for (addr = addrs, first = NULL, last = NULL; addr; addr = addr->ifa_next)
+  {
     if ((addr->ifa_flags & IFF_BROADCAST) && addr->ifa_broadaddr &&
         addr->ifa_broadaddr->sa_family == AF_INET &&
 	(!ifname || !strcmp(ifname, addr->ifa_name)))
     {
-      current = calloc(1, sizeof(http_addrlist_t));
+      if ((current = calloc(1, sizeof(http_addrlist_t))) != NULL)
+      {
+	memcpy(&(current->addr), addr->ifa_broadaddr,
+	       sizeof(struct sockaddr_in));
 
-      memcpy(&(current->addr), addr->ifa_broadaddr,
-             sizeof(struct sockaddr_in));
+	if (!last)
+	  first = current;
+	else
+	  last->next = current;
 
-      if (!last)
-        first = current;
-      else
-        last->next = current;
-
-      last = current;
+	last = current;
+      }
     }
+  }
 
   freeifaddrs(addrs);
 
@@ -974,9 +983,15 @@ read_snmp_response(int fd)		/* I - SNMP socket file descriptor */
 	_cupsSNMPWrite(fd, &(packet.address), CUPS_SNMP_VERSION_1,
 	               packet.community, CUPS_ASN1_GET_REQUEST,
 		       DEVICE_ID, LexmarkDeviceIdOID);
+	_cupsSNMPWrite(fd, &(packet.address), CUPS_SNMP_VERSION_1,
+		       packet.community, CUPS_ASN1_GET_REQUEST,
+		       DEVICE_ID, RicohDeviceIdOID);
 	_cupsSNMPWrite(fd, &(packet.address), CUPS_SNMP_VERSION_1,
 	               packet.community, CUPS_ASN1_GET_REQUEST,
 		       DEVICE_PRODUCT, XeroxProductOID);
+	_cupsSNMPWrite(fd, &(packet.address), CUPS_SNMP_VERSION_1,
+		       packet.community, CUPS_ASN1_GET_REQUEST,
+		       DEVICE_ID, HPDeviceIdOID);
         break;
 
     case DEVICE_DESCRIPTION :
